.. index::
   single: proutes; --help

.. _proutes_script:

.. autoprogram:: pyramid.scripts.proutes:PRoutesCommand.parser
    :prog: proutes

.. seealso:: :ref:`displaying_application_routes` and :ref:`running-pscripts`.
